/*
 * Copyright (c) 2010 ProfitBricks GmbH. All Rights Reserved.
 */
package org.glassfish.cditest.user.impl;


import java.util.logging.Level;
import java.util.logging.Logger;

import javax.ejb.EJBException;
import javax.ejb.Local;
import javax.ejb.Stateless;
import org.glassfish.cditest.security.api.Secure;
import org.glassfish.cditest.user.api.UserService;
import org.glassfish.cditest.user.api.model.Gender;
import org.glassfish.cditest.user.api.model.User;
import org.glassfish.cditest.user.model.UserImpl;

/**
 * <p>
 * Implementation of the UserService.
 * </p>
 * 
 * @author chaoslayer
 */
@Stateless
@Local
@Secure
public class UserServiceImpl implements UserService
{
    private static final Logger LOG = Logger.getLogger(UserService.class.getName());

    /**
     * <p>
     * Add a new user
     * </p>
     * 
     * <p>
     * The implementation must ensure that the provided user object is persisted
     * before returning the assigned persistent user ID.
     * </p>
     * 
     * @param user
     *            The user object to persist
     * @return The newly created persistent ID of the user object
     * 
     * @see UserImpl
     */
    @Override
    public Long addUser(final User user) throws EJBException
    {
        LOG.log(Level.INFO, "Storing user {0}", user);

        return new Long(123);
    }

    /**
     * <p>
     * Get a {@link User} by the user id
     * </p>
     * 
     * @param userid
     *            The userid to search for
     * @return A {@link User} object or <code>null</code> if no user was found
     */
    @Override
    public User findById(long userId) throws EJBException
    {
        UserImpl u = new UserImpl();

        u.setId(userId);
        u.setEmailAddress("test@test.org");
        u.setFirstName("John");
        u.setLastName("Doe");
        u.setGender(Gender.UNISEX);
        u.setUsername("john-123");

        LOG.log(Level.INFO, "Returning user {0}", u);

        return u;
    }

}
